@@ -62,7 +62,8 @@ def runList(*taskList):
             b.remove(logFile)
         logFile = b.getPath(logFolder, f"{time.strftime('%Y%m%d_%H%M%S')}.log")
         b.initLogger(logFile=logFile)
-        for moduleName, parDict in taskList:
+        for moduleName, *parList in taskList:
+            parDict = parList and parList[0] or {}
             run(moduleName, **parDict)
     except Exception:
         import traceback
@@ -73,9 +74,9 @@ def runList(*taskList):
         printcolor.resetColor()
         b.info("任务结束")
         b.remove(lockFile)
-        while True:
-            time.sleep(1)
-
+        if not isDev():
+            while True:
+                time.sleep(1)
 
 
 def run(moduleName, **parDict):
